@@ -196,6 +196,7 @@ def popGrowth(file_path):
 def evolutionDynamics(an_path, norm_path):
     an = np.array(list(map(readPaths, an_path)))
     norm = np.array(list(map(readPaths, norm_path)))
+    name = an[0,2].rstrip('_analytical_')
     _out_an = an[0,1]
     _out_norm = norm[0,1]
     ind = int(min(len(an[:,0]), len(norm[:,0]))/4)
@@ -206,7 +207,7 @@ def evolutionDynamics(an_path, norm_path):
     mWave = np.append(an[ix,[0,2,3]], norm[ix,[0,2,3]], axis=0)
     mWave = np.array(list(map(lambda x: [sc.sparse.load_npz(x[0]), x[2], 'analytical' in x[1]], mWave)))
     
-    fig, ax = plt.subplots(3,2, figsize=(40,20))
+    fig, ax = plt.subplots(3,2, figsize=(30,30))
     fig.tight_layout(pad=10.0)
     
     ax[0,0].plot(mWave[0,0][:,0].toarray(), mWave[0,0][:,1].toarray(), 'k', linewidth='4')
@@ -253,7 +254,7 @@ def evolutionDynamics(an_path, norm_path):
                               an[:,0] , mean[:,1])))
     norm_war = np.array(list(map(lambda x, y: sum((x[:,1].toarray()-float(y))**2)/len(x[:,1].toarray()), \
                             norm[:,0], mean[:,2])))
-    war = np.array(list(map(lambda x, y, z: [float(x), y, z], an[:,1], an_war, norm_war)))   
+    war = np.array(list(map(lambda x, y, z: [float(x), float(y), float(z)], an[:,1], an_war, norm_war)))   
     
     ax[0,1].plot(mean[:,0], mean[:,1], 'k', linewidth='4')
     ax[0,1].plot(mean[:,0], mean[:,2], 'r', linewidth='2')
@@ -276,6 +277,7 @@ def evolutionDynamics(an_path, norm_path):
     ax[0,1].set_title("mean number of mutations, $\chi(t)$", fontdict={'fontsize':50})
     ax[1,1].set_title("variance number of mutations, $\sigma^{2}(t)$", fontdict={'fontsize':50})
     ax[2,1].set_title("population size, N(t)", fontdict={'fontsize':50})
+    ax[2,1].set_xlabel("time, t", fontdict={'fontsize':30})
     
     try:
         os.makedirs(_out_an, exist_ok=True) 
@@ -283,13 +285,11 @@ def evolutionDynamics(an_path, norm_path):
     except OSError as error:
         print(error)
     finally:
-        if os.path.exists(_out_an + "evolution_dynamics.jpg"):
-            os.remove(_out_an + "evolution_dynamics.jpg")
-        if os.path.exists(_out_norm + "evolution_dynamics.jpg"):
-            os.remove(_out_norm + "evolution_dynamics.jpg")
-        fig.savefig(_out_an + "evolution_dynamics.jpg")
-        fig.savefig(_out_norm + "evolution_dynamics.jpg")
+        if os.path.exists(_out_an + "evolution_dynamics_" + name + ".jpg"):
+            os.remove(_out_an + "evolution_dynamics_" + name + ".jpg")
+        if os.path.exists(_out_norm + "evolution_dynamics_" + name + ".jpg"):
+            os.remove(_out_norm + "evolution_dynamics_" + name + ".jpg")
+        fig.savefig(_out_an + "evolution_dynamics_" + name + ".jpg")
+        fig.savefig(_out_norm + "evolution_dynamics_" + name + ".jpg")
         plt.close(fig)  
     
-if __name__ == '__main__':
-    mutationWave(['E:/Simulations/Mutation waves in cancer cells/Normal/third/third_normal_4975.npz'])
