@@ -12,10 +12,10 @@ import re
 from threading import Thread
 from multiprocessing import Process, Queue
 
-# from seEvo_evolution_init import seEvoInit
-# import externalPlots as externalPlots
-from seEvo1D.seEvo_evolution_init import seEvoInit
-import seEvo1D.externalPlots as externalPlots
+from seEvo_evolution_init import seEvoInit
+import externalPlots as externalPlots
+# from seEvo1D.seEvo_evolution_init import seEvoInit
+# import seEvo1D.externalPlots as externalPlots
 
 disclaimer = '''
     seEvo - slightly effect evolution simulator basing on Gillespie algorithm.
@@ -319,7 +319,7 @@ class mainFormat(qtWidget.QWidget):
         layout.addWidget(qtWidget.QLabel("number of steps,(optional: 'cells' as type of break - population size)"), row, 2)
         row = row + 1
         self._tau = qtWidget.QLineEdit(str(0.005))     
-        layout.addWidget(qtWidget.QLabel("Tau step, tau * Nc/N"), row, 0)
+        layout.addWidget(qtWidget.QLabel("Tau step"), row, 0)
         layout.addWidget(self._tau, row, 1)
         layout.addWidget(qtWidget.QLabel("min: 0, max: 1, step: 0.001"), row, 2)
         row = row + 1
